ltm, rasch and tpm models.person.fit(object, alternative = c("less", "greater", "two.sided"),
resp.patterns = NULL, FUN = NULL, simulate.p.value = FALSE,
B = 1000)ltm, class rasch or class tpm.NULL
the person fit statistics are computed for the observed response patterns.TRUE, then the Monte Carlo procedure described in the Details
section is used to approximate the the distribution of the person-fit statistic(s) under the null hypothesis.persFit is a list with components,statistic argument.FUN argument.alternative argument.B argument.object.FUN = NULL) by person.fit() are the $L_0$ statistic
of Levine and Rubin (1979) and its standardized version $L_z$ proposed by Drasgow et al. (1985).
If simulate.p.value = FALSE, the $p$-values are calculated for the $L_z$ assuming a standard normal
distribution for the statistic under the null. If simulate.p.value = TRUE, a Monte Carlo procedure is used to
approximate the distribution of the person-fit statistic(s) under the null hypothesis. In particular, the following
steps are replicated B times for each response pattern:
[object Object],[object Object],[object Object]
Denote by $T_{obs}$ the value of the person-fit statistic for the original data-set. Then the $p$-value is
approximated according to the formula $$\left(1 + \sum_{b = 1}^B I(T_b \leq T_{obs})\right) / (1 + B),$$ if alternative = "less", $$\left(1 + \sum_{b = 1}^B I(T_b \geq
T_{obs})\right) / (1 + B),$$ if alternative = "greater", or
$$\left(1 + \sum_{b = 1}^B I(|T_b| \geq |T_{obs}|)\right) / (1 + B),$$ if alternative = "two.sided", where $T_b$ denotes the value of the person-fit statistic in the
$b$th simulated data-set, $I(.)$ denotes the indicator function, and $|.|$ denotes the absolute value.
For the $L_z$ statistic, negative values (i.e., alternative = "less") indicate response patterns that
are unlikely, given the measurement model and the ability estimate. Positive values (i.e., alternative =
"greater") indicate that the examinee's response pattern is more consistent than the probabilistic IRT model
expected. Finally, when alternative = "two.sided" both the above settings are captured.
This simulation scheme explicitly accounts for the fact that ability values are estimated, by drawing
from their large sample distribution. Strictly speaking, drawing $z^*$ from a normal distribution is not
theoretically appropriate, since the posterior distribution for the latent abilities is not normal. However, the
normality assumption will work reasonably well, especially when a large number of items is considered.item.fit,
margins,
GoF.rasch,# person-fit statistics for the Rasch model
# for the Abortion data-set
person.fit(rasch(Abortion))
# person-fit statistics for the two-parameter logistic model
# for the LSAT data-set
person.fit(ltm(LSAT ~ z1), simulate.p.value = TRUE, B = 100)Run the code above in your browser using DataLab