## S3 method for class 'gpcm':
residuals(object, resp.patterns = NULL, order = TRUE, \dots)
## S3 method for class 'grm':
residuals(object, resp.patterns = NULL, order = TRUE, \dots)
## S3 method for class 'ltm':
residuals(object, resp.patterns = NULL, order = TRUE, \dots)
## S3 method for class 'rasch':
residuals(object, resp.patterns = NULL, order = TRUE, \dots)
## S3 method for class 'tpm':
residuals(object, resp.patterns = NULL, order = TRUE, \dots)gpcm, class grm, class ltm, class rasch or class
tpm.matrix or a data.frame of response patterns with columns denoting the
items; if NULL the expected frequencies are computed for the observed response patterns.TRUE the response patterns are sorted according to the residual estimates.matrix containing the observed and expected frequencies as well as the residual value for
each response pattern.fitted.gpcm,
fitted.grm,
fitted.ltm,
fitted.rasch,
fitted.tpmfit <- ltm(LSAT ~ z1)
residuals(fit)
residuals(fit, order = FALSE)Run the code above in your browser using DataLab